Class: Azure::CognitiveServices::TextAnalytics::V2_1::Models::MatchRecord

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb

Overview

Model object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#entity_type_scoreFloat

number denoting the confidence level of the entity type will be returned.

Returns:

  • (Float)

    (optional) If an entity type is recognized, a decimal



24
25
26
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb', line 24

def entity_type_score
  @entity_type_score
end

#lengthInteger

text.

Returns:

  • (Integer)

    Length (in Unicode characters) for the entity match



35
36
37
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb', line 35

def length
  @length
end

#offsetInteger

match text.

Returns:

  • (Integer)

    Start position (in Unicode characters) for the entity



31
32
33
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb', line 31

def offset
  @offset
end

#textString

Returns Entity text as appears in the request.

Returns:

  • (String)

    Entity text as appears in the request.



27
28
29
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb', line 27

def text
  @text
end

#wikipedia_scoreFloat

recognized, a decimal number denoting the confidence level of the Wikipedia info will be returned.

Returns:

  • (Float)

    (optional) If a well-known item with Wikipedia link is



19
20
21
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb', line 19

def wikipedia_score
  @wikipedia_score
end

Class Method Details

.mapperObject

Mapper for MatchRecord class as Ruby Hash. This will be used for serialization/deserialization.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/match_record.rb', line 42

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'MatchRecord',
    type: {
      name: 'Composite',
      class_name: 'MatchRecord',
      model_properties: {
        wikipedia_score: {
          client_side_validation: true,
          required: false,
          serialized_name: 'wikipediaScore',
          type: {
            name: 'Double'
          }
        },
        entity_type_score: {
          client_side_validation: true,
          required: false,
          serialized_name: 'entityTypeScore',
          type: {
            name: 'Double'
          }
        },
        text: {
          client_side_validation: true,
          required: false,
          serialized_name: 'text',
          type: {
            name: 'String'
          }
        },
        offset: {
          client_side_validation: true,
          required: false,
          serialized_name: 'offset',
          type: {
            name: 'Number'
          }
        },
        length: {
          client_side_validation: true,
          required: false,
          serialized_name: 'length',
          type: {
            name: 'Number'
          }
        }
      }
    }
  }
end