Class: Azure::CognitiveServices::TextAnalytics::V2_1::Models::SentimentBatchResult
- Inherits:
-
Object
- Object
- Azure::CognitiveServices::TextAnalytics::V2_1::Models::SentimentBatchResult
- Includes:
- MsRestAzure
- Defined in:
- lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result.rb
Overview
Model object.
Instance Attribute Summary collapse
-
#documents ⇒ Array<SentimentBatchResultItem>
Response by document.
-
#errors ⇒ Array<ErrorRecord>
Errors and Warnings by document.
-
#statistics ⇒ RequestStatistics
in the request this field will contain information about the request payload.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for SentimentBatchResult class as Ruby Hash.
Instance Attribute Details
#documents ⇒ Array<SentimentBatchResultItem>
Returns Response by document.
17 18 19 |
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result.rb', line 17 def documents @documents end |
#errors ⇒ Array<ErrorRecord>
Returns Errors and Warnings by document.
20 21 22 |
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result.rb', line 20 def errors @errors end |
#statistics ⇒ RequestStatistics
in the request this field will contain information about the request payload.
25 26 27 |
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result.rb', line 25 def statistics @statistics end |
Class Method Details
.mapper ⇒ Object
Mapper for SentimentBatchResult class as Ruby Hash. This will be used for serialization/deserialization.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result.rb', line 32 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'SentimentBatchResult', type: { name: 'Composite', class_name: 'SentimentBatchResult', model_properties: { documents: { client_side_validation: true, required: false, read_only: true, serialized_name: 'documents', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'SentimentBatchResultItemElementType', type: { name: 'Composite', class_name: 'SentimentBatchResultItem' } } } }, errors: { client_side_validation: true, required: false, read_only: true, serialized_name: 'errors', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'ErrorRecordElementType', type: { name: 'Composite', class_name: 'ErrorRecord' } } } }, statistics: { client_side_validation: true, required: false, read_only: true, serialized_name: 'statistics', type: { name: 'Composite', class_name: 'RequestStatistics' } } } } } end |