Class: Azure::CognitiveServices::TextAnalytics::V2_1::Models::SentimentBatchResultItem

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result_item.rb

Overview

Model object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#idString

Returns Unique, non-empty document identifier.

Returns:

  • (String)

    Unique, non-empty document identifier.



17
18
19
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result_item.rb', line 17

def id
  @id
end

#scoreFloat

of the document. A score above 0.7 usually refers to a positive document while a score below 0.3 normally has a negative connotation. Mid values refer to neutral text.

Returns:

  • (Float)

    A decimal number between 0 and 1 denoting the sentiment



23
24
25
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result_item.rb', line 23

def score
  @score
end

#statisticsDocumentStatistics

in the request this field will contain information about the document payload.

Returns:



28
29
30
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result_item.rb', line 28

def statistics
  @statistics
end

Class Method Details

.mapperObject

Mapper for SentimentBatchResultItem class as Ruby Hash. This will be used for serialization/deserialization.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/v2.1/generated/azure_cognitiveservices_textanalytics/models/sentiment_batch_result_item.rb', line 35

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'SentimentBatchResultItem',
    type: {
      name: 'Composite',
      class_name: 'SentimentBatchResultItem',
      model_properties: {
        id: {
          client_side_validation: true,
          required: false,
          serialized_name: 'id',
          type: {
            name: 'String'
          }
        },
        score: {
          client_side_validation: true,
          required: false,
          serialized_name: 'score',
          type: {
            name: 'Double'
          }
        },
        statistics: {
          client_side_validation: true,
          required: false,
          serialized_name: 'statistics',
          type: {
            name: 'Composite',
            class_name: 'DocumentStatistics'
          }
        }
      }
    }
  }
end